H5PRequestModel class

Model class for handling H5P file requests.

Constructors

H5PRequestModel({required String refName, required String url, String? error, H5PFileStatus status = H5PFileStatus.undefined, int priority = 0, String? localPath})
H5PRequestModel.fromJson(Map<String, dynamic> json)
Create from JSON
factory

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
localPath String?
Local path where the downloaded .h5p file is stored
final
priority int
final
refName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status H5PFileStatus
final
url String
final

Methods

copyWith({String? refName, String? url, String? error, H5PFileStatus? status, int? priority, String? localPath}) H5PRequestModel
Copy model with updated fields
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited